import * as eslint from 'eslint';
import * as jsonc_eslint_parser from 'jsonc-eslint-parser';
import { PackageJsonRuleContext } from './createRule.mjs';
import 'estree';

declare const plugin: {
    meta: {
        name: string;
        version: string;
    };
    rules: {
        "order-properties": {
            create(context: PackageJsonRuleContext<[({
                order: "legacy" | "sort-package-json" | string[];
            } | undefined)?]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "repository-shorthand": {
            create(context: PackageJsonRuleContext<[({
                form: "object" | "shorthand";
            } | undefined)?]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "sort-collections": {
            create(context: PackageJsonRuleContext<string[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "unique-dependencies": {
            create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "valid-local-dependency": {
            create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "valid-name": {
            create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "valid-package-def": {
            create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "valid-repository-directory": {
            create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
        "valid-version": {
            create(context: PackageJsonRuleContext<unknown[]>): jsonc_eslint_parser.RuleListener;
            meta: eslint.Rule.RuleMetaData;
        };
    };
};
declare const recommendedRuleSettings: {
    [k: string]: "error";
};

export { plugin, recommendedRuleSettings };
